@@ -4,9 +4,11 @@ from abc import ABC
 import boto3
 from botocore.config import Config
 
-from py_aws_core import logs, secrets_manager
+from py_aws_core import logs
+from py_aws_core.secrets_manager import get_secrets_manager
 
 logger = logs.logger
+secrets_manager = get_secrets_manager()
 
 COGNITO_CLIENT_CONNECT_TIMEOUT = 4.9
 COGNITO_CLIENT_READ_TIMEOUT = 4.9
@@ -20,10 +22,10 @@ class CognitoClient:
             total_max_attempts=2,
         )
     )
+    __boto3_session = boto3.Session()
 
     def __init__(self):
         self._boto_client = None
-        self._secrets_manager = secrets_manager.SecretsManager()
 
     @property
     def boto_client(self):
@@ -37,25 +39,25 @@ class CognitoClient:
 
     @property
     def aws_cognito_pool_client_id(self):
-        return self._secrets_manager.get_secret(secret_name='AWS_COGNITO_POOL_CLIENT_ID')
+        return secrets_manager.get_secret(secret_name='AWS_COGNITO_POOL_CLIENT_ID')
 
     @property
     def aws_cognito_pool_id(self):
-        return self._secrets_manager.get_secret(secret_name='AWS_COGNITO_POOL_ID')
+        return secrets_manager.get_secret(secret_name='AWS_COGNITO_POOL_ID')
 
     @classmethod
     def get_new_client(cls):
         logger.info(f'Getting new Cognito client')
-        return boto3.Session().client(
+        return cls.__boto3_session.client(
             config=cls.__CONFIG,
             service_name='cognito-idp',
         )
 
     def admin_create_user(self, *args, **kwargs):
-        return self._boto_client.admin_create_user(*args, **kwargs)
+        return self.boto_client.admin_create_user(*args, **kwargs)
 
     def initiate_auth(self, *args, **kwargs):
-        return self._boto_client.initiate_auth(*args, **kwargs)
+        return self.boto_client.initiate_auth(*args, **kwargs)
 
 
 class AdminCreateUser:
@@ -157,4 +159,4 @@ class RefreshTokenAuth(ABCInitiateAuth):
             },
             ClientId=client.aws_cognito_pool_client_id(),
         )
-        return cls.Response(response)
\ No newline at end of file
+        return cls.Response(response)
